@@ -5,7 +5,7 @@ srcdir=`dirname $0`
 test -z "$srcdir" && srcdir=.
 
 PKG_NAME="gnome-documents"
-ACLOCAL_FLAGS="-I libgd"
+ACLOCAL_FLAGS="-I libgd $ACLOCAL_FLAGS"
 
 (test -f $srcdir/src/main.js) || {
     echo -n "**Error**: Directory "\`$srcdir\'" does not look like the"
@@ -18,6 +18,12 @@ which gnome-autogen.sh || {
     exit 1
 }
 
+git submodule update --init --recursive
+
+cd egg-list-box
+sh autogen.sh --no-configure
+cd ..
+
 REQUIRED_AUTOCONF_VERSION=2.59
 REQUIRED_AUTOMAKE_VERSION=1.9
 REQUIRED_INTLTOOL_VERSION=0.40.0
