@@ -182,12 +182,7 @@ const EditToolbar = new Lang.Class({
         this.parent();
 
         // back button, on the left of the toolbar
-        let iconName =
-            (this.toolbar.get_direction() == Gtk.TextDirection.RTL) ?
-            'go-next-symbolic' : 'go-previous-symbolic';
-        let backButton = new Gd.HeaderSimpleButton({ symbolic_icon_name: iconName,
-                                                     label: _("Back") });
-        this.toolbar.pack_start(backButton);
+        let backButton = this.addBackButton();
         backButton.connect('clicked', Lang.bind(this,
             function() {
                 Application.documentManager.setActiveItem(null);
